@@ -770,6 +770,21 @@ public:
 	 */
 	int getServices(void);
 
+	/**
+	 * Get the execution priority of the resolver thread.
+	 *
+	 * @return priority of resolver.
+	 */
+	int priResolver(void);
+
+	/**
+	 * Get the execution interval of the resolver thread, or
+	 * 0 if no resolver scheduler.
+	 *
+	 * @return number of minutes for interval.
+	 */
+	int getResolver(void);
+
 	/**
 	 * Get relative priority to run audio streams at.
 	 *
@@ -1874,6 +1889,16 @@ public:
 	 */
 	virtual timeout_t Stop(void);
 
+	/**
+	 * Indicate if the service thread is exiting and/or can be
+	 * deleted now.  If false, then it will be cleaned by the
+	 * scheduler thread.
+	 *
+	 * @return false if held to scheduler.
+	 */
+	virtual bool isExiting(void)
+		{return true;};
+
 	/**
 	 * Termination of service.
 	 */
@@ -1988,7 +2013,7 @@ private:
 	friend void stopServers(void);
 
 protected:
-	Server();
+	Server(int pri);
 
 	/**
 	 * Used for stopServers call interface.
@@ -2137,6 +2162,42 @@ public:
 	virtual void Refresh(int seconds) = 0;	
 };
 
+/**
+ * Sessions are used for "garbage collected" entities which may be
+ * detached and removed after an expiration time rather than falling
+ * out of scope immediately.  This process is managed by the scheduler
+ * thread.
+ */
+
+class Session
+{
+private:
+	friend class Scheduler;
+	static Mutex mutex;
+	static Session *first;
+	static Session *last;
+	Session *next, *prev;
+	static void Clean(void);
+
+protected:
+	Session();
+	virtual ~Session()
+		{Unlink();};
+
+	/**
+	 * Unlink the session object.
+	 */
+	void Unlink(void);
+
+	/**
+	 * Indicate if and when this session is to be "garbage collected"
+	 * by UNIX timestamp.
+	 *
+	 * @return 0 if still running, else garbage collection period.
+	 */
+	virtual time_t getExpires(void) = 0;
+};
+
 extern KeyServer keyserver;
 extern KeyThreads keythreads;
 extern KeyMemory keymemory;
