@@ -135,7 +135,7 @@ void KeyServer::loadGroups(void)
 	group = strtok(group, " \t\n");
 	while(group)
 	{
-		slog(SLOG_DEBUG) << "loading " << group << "trunk group" << endl;
+		slog(SLOG_DEBUG) << "loading " << group << " trunk group" << endl;
 		new TrunkGroup(group);
 		group = strtok(NULL, " \t\n");
 	}
@@ -209,6 +209,37 @@ Keydata("/bayonne/memory")
 	Load(defpaths);
 }
 
+int KeyThreads::priResolver(void)
+{
+	char *cp = getLast("resolver");
+	if(cp)
+		return atoi(cp);
+
+	return 0;
+}
+
+int KeyThreads::getResolver(void)
+{
+	char buf[32];
+	int cnt;
+	char *cp;
+
+	cp = getLast("resolver");
+	if(!cp)
+		return 0;
+
+	strcpy(buf, cp);
+	cp = strchr(buf, ',');
+	if(cp)
+	{
+		++cp;
+		while(*cp == ' ' || *cp == '\t')
+			++cp;
+		return atoi(cp);
+	}
+	return 15;
+}
+
 int KeyThreads::getServices(void)
 {
 	char buf[32];
@@ -219,7 +250,7 @@ int KeyThreads::getServices(void)
 	if(cp)
 	{
 		++cp;
-		if(*cp == ' ' || *cp == '\t')
+		while(*cp == ' ' || *cp == '\t')
 			++cp;
 		cnt = atoi(cp);
 		if(cnt > 0)
@@ -621,12 +652,10 @@ void TrunkGroup::setSchedule(const char *str)
 	if(!str)
 		str = "";
 
-	if(!scheduler.isThread())
-		scheduler.WriteLock();
+	scheduler.WriteLock();
 	strncpy(schedule, str, sizeof(schedule) - 1);
 	schedule[sizeof(schedule) - 1] = 0;
-	if(!scheduler.isThread())
-		scheduler.Unlock();
+	scheduler.Unlock();
 }
 
 phTone *phTone::first = NULL;
