@@ -220,8 +220,8 @@ Database::Database()
 	database = this;
 }
 
-Server::Server() :
-Thread(NULL, keythreads.priManager())
+Server::Server(int pri) :
+Thread(NULL, pri)
 {
 	next = first;
 	first = this;
