@@ -48,6 +48,7 @@
 int tgipipe[2];
 static int *tgipids = NULL;
 static int mainpid;
+static Resolver *resolver = NULL;
 
 #ifndef	HAVE_SETENV
 static setenv(char *name, const char *value, int overwrite)
@@ -208,6 +209,9 @@ static RETSIGTYPE final(int sig)
 	if(database)
 		database->Disconnect();
 
+	if(resolver)
+		delete resolver;
+
 	if(driver)
 		driver->Stop();
 
@@ -409,6 +413,11 @@ static void initial(int argc, char **argv)
 		slog(SLOG_CRITICAL) << dso->getError() << endl;
 		final(-1);
 	}
+	catch(InetAddress *in)
+	{
+		slog(SLOG_CRITICAL) << "protocol resolver failed" << endl;
+		final(-1);
+	}
 	catch(...)
 	{
 		slog(SLOG_CRITICAL) << "unknown failure" << endl;
@@ -435,6 +444,9 @@ static void initial(int argc, char **argv)
 	if(database)
 		database->Connect();
 
+	if(keythreads.getResolver())
+		resolver = new Resolver();
+
 	startServers();
 
 	if(schedule)
