@@ -81,5 +81,46 @@ public:
 	void Stop(void);
 };
 
+// the resolver is an optional service thread.
+
+class Resolver : public Server
+{
+private:
+	static bool instance;
+	time_t interval;
+
+	void Run(void);
+	void Stop(void);
+
+public:
+	Resolver();
+};
+
+// this is a common base class for protocol configuration entries and is
+// used to support the optional resolver thread.
+
+class Protocol : public Keydata, public InetHostAddress, public ThreadLock
+{
+private:
+	friend class Resolver;
+	static Protocol *first;
+	Protocol *next;
+	Semaphore *sessions;
+	short port;
+
+	void Update(InetHostAddress &addr);
+public:
+	Protocol(const char *keypath, short port);
+	~Protocol();
+
+	InetHostAddress getAddress(void);
+
+	inline short getPort(void)
+		{return port;};
+	
+	inline Semaphore *getSessions(void)
+		{return sessions;};
+};
+
 extern Scheduler scheduler;
 extern int tgipipe[2];
